#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/7/27 4:35 下午
# @Author  : Meng Wang
# @Site    : 
# @File    : file_uploader.py
# @Software: PyCharm

import requests
from requests_toolbelt.multipart.encoder import MultipartEncoder
import json


def upload_file(access_token, org_id, upload_url):
    multipart_data = MultipartEncoder(
        fields={
            # a file upload field
            'file': ("logo.png", open('logo.png', 'rb'), 'text/plain'),
            # plain text fields
            'orgId': str(org_id),
            'type': "room"
        }
    )

    headers = {
        "Authorization": "Bearer " + access_token,
        'Content-Type': multipart_data.content_type
    }
    try:
        response = requests.post(upload_url, data=multipart_data,
                                 headers=headers, timeout=15).text
        res_dict = json.loads(response)
        if res_dict["success"]:
            #上传成功
            return res_dict["data"]["downAddress"]

        return None
    except Exception as e:
        return None



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/7/20 1:58 下午
# @Author  : Meng Wang
# @Site    : 
# @File    : mysql_client.py
# @Software: PyCharm

import pymysql

class MysqlClient(object):

    def __init__(self, ip, port, username, password, db_name=""):
        self.connection = pymysql.connect(
            host=ip,
            user=username,
            passwd=password,
            db=db_name,
            port=int(port),
            charset='utf8',
            autocommit=True,
            cursorclass=pymysql.cursors.DictCursor
        )

    def query_by_sql(self, query_sql):
        cursor = self.connection.cursor()
        try:
            # 执行sql语句
            cursor.execute(query_sql)
            # 提交到数据库执行
            results = cursor.fetchall()
            return results
        except:
            # 如果发生错误则回滚
            self.connection.rollback()
        finally:
            # 关闭数据库连接
            self.connection.close()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/7/28 4:43 下午
# @Author  : Meng Wang
# @Site    : 
# @File    : test_handler.py
# @Software: PyCharm
from abc import ABCMeta, abstractmethod

"""
测试处理器  主要运行当前主要的测试流程链
"""

"""
处理器基类
"""


class Handler(metaclass=ABCMeta):
    """
        @:parameter nginx_ip
        :parameter nginx_ip
    """

    @abstractmethod
    def process(self, nginx_ip):
        pass


"""
Database
"""


class DatabaseHandler(Handler):
    def process(self, nginx_ip):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/7/20 1:44 下午
# @Author  : Meng Wang
# @Site    : 
# @File    : __init__.py.py
# @Software: PyCharm
__VER__ = '1.0.0'
__AUTHOR = "Meng Wang @ wmlucas.cn@gmail.com"




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/9/22 8:33 上午
# @Author  : Meng Wang
# @Site    :
# @File    : processor.py
# @Software: PyCharm
import time

from influxdb import InfluxDBClient
import datetime
import socket
from loguru import logger
import vthread

"""
核心处理器
"""

INFLUX_MEASUREMENT_PREFIX = "monitor_"
# 获取主机名
hostname = socket.gethostname()
# 获取IP
host_ip = socket.gethostbyname(hostname)


class Exposer(object):
    """
        应用名称  event-merger
    """
    app_name = None
    """
        influxdb 主机 192.168.100.207
    """
    influx_host = None
    """
        influxdb 数据库
    """
    influx_db = 'intelab'
    """
        influxdb 端口
    """
    influx_port = 8086
    """
        influxdb 用户名
    """
    influx_user = "admin"
    """
        influxdb 密码
    """
    influx_password = 'admin'
    """
        存储策略
    """
    influx_rp = None

    """
        检测任务多久跑一次 也就是定时器的timer 默认60（s）
    """
    timer_duration = 60

    def __init__(self, app_name, influx_host, influx_db, influx_port, influx_user, influx_password, influx_rp,
                 timer_duration):
        self.app_name = app_name
        self.influx_host = influx_host
        self.influx_db = influx_db
        self.influx_user = influx_user
        self.influx_password = influx_password
        self.influx_port = influx_port
        self.influx_rp = influx_rp
        self.timer_duration = timer_duration

    def expose_data_to_influxdb(self):
        conn_db = InfluxDBClient(self.influx_host, str(self.influx_port), self.influx_user, self.influx_password,
                                 self.influx_db)
        current_time = datetime.datetime.utcnow().isoformat("T")
        timer_data = [
            {
                "measurement": INFLUX_MEASUREMENT_PREFIX + self.app_name,
                "time": current_time,
                "tags": {
                    "ip": host_ip
                },
                "fields": {"status": 1.0}
            }
        ]

        conn_db.write_points(points=timer_data, retention_policy=self.influx_rp)  # 写入数据，同时创建表
        logger.debug("{} monitor job added succeed!", self.app_name)
        conn_db.close()

    @vthread.pool(1)
    def init_work_main_thread(self):
        while True:
            self.expose_data_to_influxdb()
            time.sleep(self.timer_duration)

    """
        任务执行
    """

    def start(self):
        self.init_work_main_thread()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from distutils.core import setup
from setuptools import find_packages

with open("README.rst", "r") as f:
    long_description = f.read()

setup(name='py3_service_check',  # 包名
      version='0.0.2.alpha',  # 版本号
      description='python3自动化检测',
      long_description=long_description,
      author='Meng Wang',
      author_email='wmlucas@163.com',
      url='https://mp.weixin.qq.com/s/9FQ-Tun5FbpBepBAsdY62w',
      install_requires=[
        "influxdb",
        "loguru",
        "vthread"
      ],
      license='MIT License',
      packages=find_packages(),
      platforms=["all"],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Topic :: Software Development :: Libraries'
      ],
      )
